#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Feb 22 17:03:34 2022

@author: zengke
"""

from sklearn.base import BaseEstimator

class RFECVSelector(BaseEstimator):
    
    def __init__(self):
        pass
        
    def transform(self,X,y):
        """ 
        变量筛选
        """

        return self
          
    def fit(self,X,y):

        return self       